@@ -87,7 +87,6 @@ void printbuffersingle(tOutput* output,tBuffer* hBuf1,tInt64 cursorpos1,tUInt64
 	int addrwidth;
 	int bytesperline;
 	tInt32 intpos1;
-	tInt32 charcnt;
 
 
 
@@ -120,7 +119,6 @@ void printbuffersingle(tOutput* output,tBuffer* hBuf1,tInt64 cursorpos1,tUInt64
 	intpos1=getbufferidx(hBuf1,firstpos1);
 	if (intpos1>=0)
 	{
-		charcnt=0;
 		for (i=0;i<LINES-2;i++)
 		{
 			tBool colhex;
@@ -202,7 +200,6 @@ void printbufferdiff(tOutput* output,tBuffer* hBuf1,tBuffer* hBuf2,tInt64 cursor
 	tInt32 intpos1b;
 	tInt32 intpos2;
 	tInt32 intpos2b;
-	tInt32 charcnt;
 	uicolors oldcolor;
 
 
@@ -263,7 +260,6 @@ void printbufferdiff(tOutput* output,tBuffer* hBuf1,tBuffer* hBuf2,tInt64 cursor
 	}
 	if (intpos1>=0 || intpos2>=0)
 	{
-		charcnt=0;
 		intpos1b=intpos1;
 		intpos2b=intpos2;
 
@@ -407,7 +403,7 @@ void printmainmenu(tOutput* output,tBool diffmode)
 {
 	int i;
 	int x;
-	unsigned char* menutextsnodiff[]={
+	char* menutextsnodiff[]={
 "Goto  ",	// F1
 "Search",	// F2
 "Next  ",	// F3
@@ -419,7 +415,7 @@ void printmainmenu(tOutput* output,tBool diffmode)
 "Undo  ",	// F9
 "Quit  "};	// F10
 
-	unsigned char* menutextsdiff[]={
+	char* menutextsdiff[]={
 "      ",	// F1
 "      ",	// F2
 "Next  ",	// F3
