@@ -11,7 +11,7 @@ void	clearsearch(tSearch* search)
 	memset(search,0,sizeof(tSearch));
 	search->forwardnotbackward=1;
 }
-tInt8	searchfor(tSearch* search,tBuffer* buf,tUInt64* cursorpos,tBool nextnotprev)
+tInt8	searchfor(tSearch* search,tBuffer* buf,tInt64* cursorpos,tBool nextnotprev)
 {
 	tInt64	actcursorpos=*cursorpos;
 	tInt64	oldcursorpos=*cursorpos;
@@ -77,9 +77,8 @@ tInt8	searchfor(tSearch* search,tBuffer* buf,tUInt64* cursorpos,tBool nextnotpre
 						// state 2: read until the end of the line
 			tUInt64	x=0;
 			tBool	havenum;
-			tInt64	firstsearchlogpos;
+			int n;
 
-			firstsearchlogpos=search->lastsearchlogpos;
 			
 			setfilepos(frlog,search->lastsearchlogpos);
 			havenum=0;
@@ -90,9 +89,9 @@ tInt8	searchfor(tSearch* search,tBuffer* buf,tUInt64* cursorpos,tBool nextnotpre
 				state=0;
 				while (c>=32 && !done)
 				{
-					fread(&c,sizeof(char),1,frlog);
+					n=fread(&c,sizeof(char),1,frlog);
 					done=feof(frlog);
-					if (!done)
+					if (!done && n)
 					{
 						if (c=='#') state=2;
 						if (c>='a' && c<='z') c-=32;
