@@ -5,7 +5,7 @@
 #include "search.h"
 #include "output.h"
 #include "correlation.h"
-void searchmask(tOutput* output,tSearch* search,tBuffer* buf,tUInt64* cursorpos);
+void searchmask(tOutput* output,tSearch* search,tBuffer* buf,tInt64* cursorpos);
 tInt8 savedialog(tOutput* output,tBuffer* buf);
 tInt8 correlationmask(tOutput* output,tCorrelation* correlation);
 #endif
